---
title: Release 0.1.4
---

## Release 0.1.4

[Release 0.1.4](https://github.com/inventree/InvenTree/releases/tag/0.1.4) (November 2020) provides a number of major new features and improvements, as well as some crucial bug fixes:

### Build Management System

The build management system has received a major upgrade, bringing the following improvements:

#### Partial Build Completion

Previously, build orders had to be completed *atomically* (i.e. if the build order was to create 20x units, then all 20x units had to be created at once).

The new build system allows the user to specify build *outputs* (of varying quantities) against a given build order. The build order cannot be completed until all build outputs are fulfilled.

A *Build Output* is simply a StockItem object which is marked as *in production*. This stock item can be assigned a (unique) serial number which is useful for pre-allocation purposes. It also allows stock to be filtered by production status and determine how many units are being built.

#### Stock Item Tracking

Parts which are marked as *trackable* are now treated differently for the purpose of a build order. Stock items must be assigned against each build output (as was the case previously). When a build output is marked as complete, any *trackable* stock items which are assigned to that build output are installed *into* the build output (which is simply a StockItem). In this manner, if a *trackable* stock item is used to build another stock item, it remains tracked via the stock item it is installed into.

Stock items which are not *trackable* are simply removed from stock when the build output is completed.

#### Stock Allocation Improvements

A number of UX improvements have been made to simplify the process of allocating stock items against a build output (and thus a build order).

### Related Parts

Related Part denotes a relationship between two parts, when users want to show their usage is "related" to another part or simply emphasize a link between two parts.

#### Implementation

- New PartRelated model/table to store relationships between parts (requires migration)
- New Related tab shown in Part detail page
- Ability to add relationships between parts through both main and admin interfaces
- Can only manage relationship if user has "change" permission on Part ruleset

#### Example View

{% with id="related_parts_example", url="https://user-images.githubusercontent.com/4020546/96306587-8f2d0b80-0fc5-11eb-8fdb-20cb2dabfcc6.png", description="Related Parts Example View" %}
{% include 'img.html' %}
{% endwith %}

### InvenTree "Global" Settings

Global settings control the default value of fields across the entire web interface, for all-users.

!!! TODO
	More information to come soon

Also, dedicated settings sections were added for:

- Category
- Build
- Purchase Order
- Sales Order

For Category section, read [Category Parameter Templates](#category-parameter-templates)

Other section allows to set the prefix of build, puchase and sales orders.

### Category Parameter Templates

Added support for configuring parameter templates defined by categories.

#### Features

* User can now setup a list of parameter templates for each (or all) part category(ies) in InvenTree settings
* During part creation, part parameters are automatically created using the list of parameter templates from the parent category it belongs to (if option is enabled)

#### Screenshots

* Select category

{% with id="related_parts_example", url="https://user-images.githubusercontent.com/4020546/98037571-c2ef9a00-1de9-11eb-96a1-542b18cdda7e.png", description="Select Category" %}
{% include 'img.html' %}
{% endwith %}

* Add parameter template

{% with id="related_parts_example", url="https://user-images.githubusercontent.com/4020546/98145792-1cfb6880-1e99-11eb-82eb-c96d1ba9541a.png", description="Add Parameter Template" %}
{% include 'img.html' %}
{% endwith %}

* Control global behavior within part settings

{% with id="related_parts_example", url="https://user-images.githubusercontent.com/4020546/98130420-39db7000-1e88-11eb-9ca0-78370e19ccdd.png", description="Global Settings For Category Templates" %}
{% include 'img.html' %}
{% endwith %}

* Control instance behavior during part creation

{% with id="related_parts_example", url="https://user-images.githubusercontent.com/4020546/98130496-4f509a00-1e88-11eb-9239-4dc215cbc620.png", description="Instance Settings For Category Templates" %}
{% include 'img.html' %}
{% endwith %}

### Currency Support

A more comprehensive implementation of Currency support has been implemented.

Using the [django-money](https://github.com/django-money/django-money) library enables native support for all currency types, and the (future) possibility of offering real-time currency conversion.

This update is "simply" an architectural change which will allow more comprehensive currency management in a future release.

As part of the new currency library implementation, InvenTree can now track purchase price of stock items (in whichever currency the user chooses).
